summary refs log tree commit diff
path: root/pkgs/development/tools/profiling/EZTrace
diff options
context:
space:
mode:
authorJohn Ericson <John.Ericson@Obsidian.Systems>2017-10-16 14:46:37 -0400
committerJohn Ericson <John.Ericson@Obsidian.Systems>2017-11-13 00:47:48 -0500
commitf72bffb4c4178bf648bffff2a6692684f69551cd (patch)
tree8d12349092dbfaceb54dccaa0155ebd5d6d62a93 /pkgs/development/tools/profiling/EZTrace
parentde28bd48321a3e9ed5da005e69e01862e5551873 (diff)
downloadnixpkgs-f72bffb4c4178bf648bffff2a6692684f69551cd.tar
nixpkgs-f72bffb4c4178bf648bffff2a6692684f69551cd.tar.gz
nixpkgs-f72bffb4c4178bf648bffff2a6692684f69551cd.tar.bz2
nixpkgs-f72bffb4c4178bf648bffff2a6692684f69551cd.tar.lz
nixpkgs-f72bffb4c4178bf648bffff2a6692684f69551cd.tar.xz
nixpkgs-f72bffb4c4178bf648bffff2a6692684f69551cd.tar.zst
nixpkgs-f72bffb4c4178bf648bffff2a6692684f69551cd.zip
eztrace: Misc cleanups
  - Use nativeBuildInputs
  - Use libraries opcodes and bfd, rather than all of binutils
Diffstat (limited to 'pkgs/development/tools/profiling/EZTrace')
-rw-r--r--pkgs/development/tools/profiling/EZTrace/default.nix13
1 files changed, 10 insertions, 3 deletions
diff --git a/pkgs/development/tools/profiling/EZTrace/default.nix b/pkgs/development/tools/profiling/EZTrace/default.nix
index 004e5dbd46e..98b38697992 100644
--- a/pkgs/development/tools/profiling/EZTrace/default.nix
+++ b/pkgs/development/tools/profiling/EZTrace/default.nix
@@ -1,4 +1,8 @@
-{ stdenv, fetchurl, autoconf, libelf, libiberty, gfortran, zlib, binutils }:
+{ stdenv
+, fetchurl, autoconf, gfortran
+, libelf, libiberty, zlib, libbfd, libopcodes
+, buildPackages
+}:
 
 stdenv.mkDerivation rec {
   version = "1.0.6";
@@ -9,12 +13,15 @@ stdenv.mkDerivation rec {
     sha256 = "06q5y9qmdn1h0wjmy28z6gwswskmph49j7simfqcqwv05gvd9svr";
   };
 
   # Goes past the rpl_malloc linking failure
   preConfigure = ''
     export ac_cv_func_malloc_0_nonnull=yes
+    substituteInPlace ./configure \
+      --replace "/usr/bin/file" "${buildPackages.file}/bin/file"
   '';
 
-  buildInputs = [ autoconf libelf libiberty gfortran zlib binutils ];
+  nativeBuildInputs = [ autoconf gfortran ];
+  buildInputs = [ libelf libiberty zlib libbfd libopcodes ];
 
   meta = {
     description = "Tool that aims at generating automatically execution trace from HPC programs";
@@ -9,12 +13,15 @@ stdenv.mkDerivation rec {
   };
 
-  # Goes past the rpl_malloc linking failure
+  # Goes past the rpl_malloc linking failure; fixes silent file breakage
   preConfigure = ''
     export ac_cv_func_malloc_0_nonnull=yes